typed_descriptors.prop
======================

.. automodule:: typed_descriptors.prop

Prop
----

.. autoclass:: typed_descriptors.prop.Prop
    :show-inheritance:
    :members:
    :special-members: __init__, __set_name__, __get__

PropFactory
-----------

.. autoclass:: typed_descriptors.prop.PropFactory
    :show-inheritance:
    :members:

T_co
----

.. autodata:: typed_descriptors.prop.T_co

ValueFunction
-------------

.. autoclass:: typed_descriptors.prop.ValueFunction
    :show-inheritance:
    :members:

cached_property
---------------

.. autofunction:: typed_descriptors.prop.cached_property

validate_value_fun
------------------

.. autofunction:: typed_descriptors.prop.validate_value_fun

value_fun_return_type
---------------------

.. autofunction:: typed_descriptors.prop.value_fun_return_type
